@@ -1,8 +1,4 @@
 import os
-
-# Import counter
-import requests as req
-
 from packaging import version
 import matplotlib as mpl
 import matplotlib.font_manager as fm
@@ -11,10 +7,11 @@ import matplotlib.font_manager as fm
 from . import cms
 from . import atlas
 from . import lhcb
+from . import alice
 from . import plot
 from . import label
 
-from . import tools
+from ._tools import Config
 
 # Get styles directly, also available within experiment helpers.
 from . import styles as style
@@ -23,7 +20,6 @@ from .plot import (
     histplot,
     hist2dplot,
     mpl_magic,
-    r_align,
     yscale_legend,
     ylow,
     rescale_to_axessize,
@@ -34,6 +30,22 @@ from .plot import (
     save_variations,
 )
 
+## Configs
+rcParams = Config(
+    label=Config(
+        data=None,
+        paper=None,
+        supplementary=None,
+        year=None,
+        lumi=None,
+        llabel=None,
+        rlabel=None,
+    ),
+    text=Config(
+        text=None,
+    ),
+)
+
 # Make __version__ available
 try:
     _base_dir = os.path.dirname(os.path.abspath(__file__))
@@ -66,9 +78,9 @@ __all__ = [
     cms,
     atlas,
     lhcb,
+    alice,
     plot,
     style,
-    tools,
     label,
     # Log plot functions
     "histplot",
@@ -83,21 +95,3 @@ __all__ = [
     "append_axes",
     "sort_legend",
 ]
-
-# Ping import counter for stats
-# Check if CI
-istravis = os.environ.get("TRAVIS") == "true"
-isactions = os.environ.get("GITHUB_ACTIONS") == "true"
-istests = os.environ.get("RUNNING_PYTEST") == "true"
-if not (istravis | isactions | istests):
-    try:
-        # This exists solely to justify my work on the package
-        # to my boss. If you have concerns, feel free to open
-        # an issue
-        __ping__ = req.get(
-            "https://countimports.pythonanywhere.com/"
-            "count/tag.svg?url=count_mplhep_imports",
-            timeout=1,
-        )
-    except Exception:
-        pass
